package com.winhc.max.compute.graph.job.enterprise_group;

import com.aliyun.odps.data.TableInfo;
import com.aliyun.odps.graph.GraphJob;
import com.aliyun.odps.graph.RemoveDuplicatesLoadingResolver;
import com.winhc.max.compute.graph.job.pagerank.CompanyComputingVertexResolver;
import com.winhc.max.compute.graph.util.BaseUtils;
import com.winhc.max.compute.graph.util.DateUtils;
import com.winhc.max.compute.graph.util.ParameterTool;

import java.io.IOException;

/**
 * @author: XuJiakai
 * 2023/2/7 13:58
 */
public class EnterpriseGroupJob {


    private static final String vertexTableName;
    private static final String edgeTableName;
    private static final String outputTable;

    static {
        if (BaseUtils.isWindows()) {
            vertexTableName = "tmp_xjk_test_enterprise_group_input_vertex";
            edgeTableName = "tmp_xjk_test_enterprise_group_input_edge";
            outputTable = "tmp_xjk_test_enterprise_group_out";
        } else {
            vertexTableName = "tmp_xjk_enterprise_group_input_vertex";
            edgeTableName = "tmp_xjk_enterprise_group_input_edge";
            outputTable = "tmp_xjk_enterprise_group_out";
        }
    }


    public static void main(String[] args) throws IOException {
        String nowDate = DateUtils.nowDate(DateUtils.YYYYMMDDHHMMSS).replace(" ", ".").replace(":", "");

        ParameterTool parameterTool = ParameterTool.fromArgs(args);
        String numWorkers = parameterTool.getOrDefault("numWorkers", "70");
        String workerCPU = parameterTool.getOrDefault("workerCPU", "2");
        String workerMem = parameterTool.getOrDefault("workerMem", "8192");
        String outPart = parameterTool.getOrDefault("outPart", nowDate);
        String debugVertexId = parameterTool.getOrDefault("debugVertexId", null);
        System.out.println("input args: " + String.join(" ", args));
        GraphJob job = new GraphJob();


        job.setMaxIteration(-1);
        job.setNumWorkers(Integer.parseInt(numWorkers));
        if (parameterTool.has("workerCPU")) {
            job.setWorkerCPU(Integer.parseInt(workerCPU) * 100);
        }
        if (parameterTool.has("workerMem")) {
            job.setWorkerMemory(Integer.parseInt(workerMem));
        }

        if (parameterTool.has("enableDebug")) {
           String debugIndex =  parameterTool.getOrDefault("debugIndex", null);
            job.set("winhc.debug", "true");
            job.set("winhc.debug.index", debugIndex);
            job.set("winhc.debug.debugVertexId", debugVertexId);
        } else {
            job.set("winhc.debug", "false");
        }


        job.setGraphLoaderClass(EnterpriseGroupReader.class);
        job.setVertexClass(EnterpriseGroupVertex.class);


        job.setLoadingVertexResolver(RemoveDuplicatesLoadingResolver.class);
        job.setComputingVertexResolver(CompanyComputingVertexResolver.class);
        job.setAggregatorClass(EnterpriseGroupAggregator.class);


        job.addInput(TableInfo.builder()
                .projectName("winhc_ng")
                .tableName(vertexTableName)
                .build());
        job.addInput(TableInfo.builder()
                .projectName("winhc_ng")
                .tableName(edgeTableName)
                .build());
        job.addOutput(TableInfo.builder()
                .projectName("winhc_ng")
                .tableName(outputTable)
                .partSpec("ds='" + outPart + "'")
                .build());


        long startTime = System.currentTimeMillis();
        job.run();
        System.out.println("Job Finished in "
                + (System.currentTimeMillis() - startTime) / 1000.0 + " seconds");


    }
}
